#
# spec file for package vdr
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           vdr
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  libcap-devel
BuildRequires:  libjpeg-devel
BuildRequires:  linux-glibc-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
BuildRequires:  systemd-devel
#
%define vdrname         vdr
%define vdr_apiversion  2.2.0
%define vdr_localedir   %{_datadir}/vdr/locale
%define vdr_libdir      %{_libdir}/vdr
%define vdr_includedir  %{_includedir}/vdr
%define vdr_videodir    /var/spool/video
%define vdr_sysconfdir  /etc/vdr
#
Url:            http://www.tvdr.de/
PreReq:         /usr/sbin/useradd
Version:        2.2.0
Release:        6.2
Summary:        Video Disk Recorder
License:        GPL-2.0+
Group:          Hardware/TV
Source:         ftp://ftp.tvdr.de/vdr/vdr-%{version}.tar.bz2
Source10:       vdr.macros
Source11:       vdr.firewall
Source42:       msgmerge
# generated from wiki page
Source90:       README.SUSE-vdr.txt
Source91:       README.SUSE-vdr.html
Source92:       greenish.css
Source95:       vdr-doc.desktop
#
Patch1:         vdr-1.7.29-menuselection.patch
Patch2:         vdr-1.7.21-pluginmissing.patch
Patch3:         vdr-1.7.36-wareagle.patch
Patch4:         vdr-2.2.0-dynamite.patch
Patch5:         vdr-2.0.4-MainMenuHooks-v1_0_1.patch
Patch6:         vdr-2.0.6-wareagle-fix.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       vdr-devel
Provides:       vdr(abi) = %vdr_apiversion
Obsoletes:      vdr(abi) < %vdr_apiversion
Provides:       vdrapi = %vdr_apiversion
Requires:       xorg-x11-fonts-scalable
%if 0%{?suse_version} >= 1220
Recommends:     runvdr-extreme-systemd
%else
Recommends:     vdr-runvdr
%endif

%package devel
Summary:        Video Disk Recorder
Group:          Hardware/TV
PreReq:         vdr = %version

%package devel-doc
Summary:        Video Disk Recorder
Group:          Hardware/TV
PreReq:         vdr-devel = %version
BuildArch:      noarch

%description
Version 2.0 of VDR, the Linux Video Disk Recorder provides HDTV support, the
Transport Stream recording format, DVB subtitles, ATSC support, and improved
Electronic Program Guides handling. 

%description devel
Development files for VDR, needed for building plugins.

%description devel-doc
API documentation for VDR.

%lang_package

%prep
%setup -q -n vdr-%{version}
#
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
#
cat > Make.config <<EOF
### The C compiler options:
CFLAGS   = $RPM_OPT_FLAGS -fPIC -Wall
CXXFLAGS = $RPM_OPT_FLAGS -fPIC -Wall -Werror=overloaded-virtual -Wparentheses
### The directory environment:
PREFIX   = %{_prefix}
BINDIR   = %{_bindir}
INCDIR   = %{_includedir}
LIBDIR   = %{vdr_libdir}
LOCDIR   = %{vdr_localedir}
MANDIR   = %{_mandir}
PCDIR    = %{_libdir}/pkgconfig
RESDIR   = %{_datadir}/vdr

VIDEODIR = %{vdr_videodir}
CONFDIR  = %{vdr_sysconfdir}
CACHEDIR = %{_localstatedir}/cache/vdr
LIRC_DEVICE = /var/run/lirc/lircd
VDR_USER = vdr
SDNOTIFY = 1
EOF
#
APIVERSION=`sed -ne '/define APIVERSION/s/^.*"\(.*\)".*$/\1/p' config.h`
if [ "%vdr_apiversion" !=  "$APIVERSION" ]; then
	echo "*** APIVERSION must be $APIVERSION, fix definition!"
	false
fi
# for some reason, graphviz doesn't like png here
sed -i 's|^\(DOT_IMAGE_FORMAT\s\+= \).*$|\1svg|g
        s|^\(INTERACTIVE_SVG\s\+= \).*$|\1YES|g'  Doxyfile
# do not include build date in locale files
cp -a %{SOURCE42} .
chmod 0755 msgmerge

%build
# to use msgmerge script
export PATH=`pwd`:$PATH
make %{?jobs:-j%jobs}
make plugins
make srcdoc

%install
%makeinstall
install -m 644 *.conf %{buildroot}%{vdr_sysconfdir}
install -m 644 Make.config %{buildroot}%{vdr_includedir}
install -d -m 755 %{buildroot}%{_localstatedir}/cache/vdr
# create plugins doc dir
mkdir plugins
for d in PLUGINS/src; do
    test -d PLUGINS/src/$d && {
	for f in README HISTORY COPYING; do
	    test -f PLUGINS/src/$d/$f && cp -a PLUGINS/src/$d/$f plugins/$f.$d
	done
    }
done
#
# docu
#
cp %{SOURCE90} README.SUSE
cp %{SOURCE91} README.SUSE.html
cp %{SOURCE92} .
#
install -d -m 755 %{buildroot}%{_datadir}/susehelp/meta/Manuals/Productivity
install -m 644 %{SOURCE95} %{buildroot}%{_datadir}/susehelp/meta/Manuals/Productivity/vdr.desktop
# locale files
echo '%%defattr (644, root, root, 755)' > vdr.lang
find %{buildroot}%{vdr_localedir} -type f -printf '%%P\n' | while read f; do
	echo "%%lang(${f%%%%/*}) %{vdr_localedir}/$f"
done >> vdr.lang
#
# source code docu (installed manually for the sake of fdupes' success)
install -d -m 755 %{buildroot}%{_docdir}/%{name}-devel
cp -a srcdoc/html %{buildroot}%{_docdir}/%{name}-devel
%fdupes %{buildroot}%{_docdir}/%{name}-devel
#
# rpm macro file
install -d -m 755 %{buildroot}/etc/rpm
cat > %{buildroot}/etc/rpm/macros.vdr <<EOF
%%vdrname         %vdrname
%%vdr_apiversion  %vdr_apiversion
%%vdr_localedir   %vdr_localedir
%%vdr_libdir      %vdr_libdir
%%vdr_includedir  %vdr_includedir
%%vdr_videodir    %vdr_videodir
%%vdr_sysconfdir  %vdr_sysconfdir
%%vdr_prereq      vdr(abi) = %{vdr_apiversion}
EOF
cat %{SOURCE10} >> %{buildroot}/etc/rpm/macros.vdr
#
# msgmerge helper for plugins
install -m 0755 msgmerge %{buildroot}%{_datadir}/vdr/msgmerge
#
# firewall config
install -m 644 -D %{SOURCE11} %{buildroot}/%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}

%pre
/usr/sbin/useradd -r -d %{vdr_videodir} -s /bin/false -c "Video Disk Recorder" -g video vdr 2> /dev/null || :

%files
%defattr(-,root,root)
%doc README.SUSE README.SUSE.html greenish.css
%doc %{_datadir}/susehelp
%doc COPYING README* UPDATE* CONTRIBUTORS HISTORY
%doc MANUAL channels.conf.* PLUGINS.html plugins
%attr(755,vdr,root) %dir %{vdr_videodir}
%attr(755,vdr,root) %dir %{vdr_sysconfdir}
%attr(755,vdr,root) %dir %{_localstatedir}/cache/vdr
%dir %{vdr_libdir}
%dir %{_datadir}/vdr
%dir %{vdr_localedir}
%dir %{vdr_localedir}/*
%dir %{vdr_localedir}/*/LC_MESSAGES
%attr(-,vdr,root) %config(noreplace) %{vdr_sysconfdir}/*
%{_bindir}/*
%{vdr_libdir}/*
%{_mandir}/man?/*
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}

%files devel
%defattr(-,root,root)
%config /etc/rpm/macros.vdr
%{vdr_includedir}
%{_includedir}/libsi
%{_libdir}/pkgconfig/*
%{_datadir}/vdr/msgmerge

%files devel-doc
%defattr(-,root,root)
%{_docdir}/%{name}-devel

%files lang -f %{name}.lang

%changelog
* Sat May 30 2015 seife+obs@b1-systems.com
- rebase and reenable dynamite patch
  (I have this lying around for some time, but it needs testing)
  (vdr-2.0.3-dynamite.patch -> vdr-2.2.0-dynamite.patch)
* Sat May 30 2015 seife+obs@b1-systems.com
- reapply changes which got lost in a conflicting submit request
  (originally done by Marcel Witte)
  * removed a lot of unused files (e.g. openvt.diff)
  * fixed the readme to current version
  * split out the very large devel-doc package
* Wed Mar  4 2015 seife+obs@b1-systems.com
- update to version 2.2.0, most important new features:
  * rotor support
  * VDR now reads command line options from *.conf files in
    /etc/vdr/conf.d, see vdr.1 and vdr.5 for details.
  * Added support for systemd
  * Channels that are not listed in the SDT are now only marked as
    OBSOLETE if "Setup/DVB/Update channels" is set to a value other
    than "no" or "PIDs only".
  * Added support for "Satellite Channel Routing" (SCR) according
    to EN50607, also known as "JESS"
  * Added support for LCN (Logical Channel Numbers), which plugins
    may use to sort channels
  * dropped support for distributed video directory over multiple
    disks
  * lots of bug fixes
  * see HISTORY for more details
- see the UPDATE-2.2.0 file for migration hints, too
- the dynamite patch is disabled for now as it does not apply
- vdrapi version changed to 2.2.0
* Wed Feb  4 2015 seife+obs@b1-systems.com
- update to 2.0.7:
  * Fixed a possible division by zero in frame rate detection.
  * Fixed jumping to an absolute position via the Red key in case
    replay was paused
  * Now returning from removing deleted recordings after at most
    10 seconds, or if the user presses a remote control key, to
    keep the system from getting unresponsive when removing a huge
    number of files
  * Fixed generating the index file of an existing recording in
    case at the of a TS file there is less data in the buffer than
    needed by the frame detector. In such a case it was possible
    that frames were missed, and there was most likely a distortion
    when replaying that part of a recording. This is mostly a
    problem for recordings that consist of more than one *.ts file.
    Single file recordings could only lose some frames at their
    very end. At any rate, if you have generated an index file with
    VDR version 2.0.6 you may want to do so again with this version
    to make sure the index is OK.
- vdrapi version stays at 2.0.6
* Wed Sep  3 2014 wagner-thomas@gmx.at
- fixed wrong writing of SUSE
- added template for SuSEfirewall2
* Fri Jul 25 2014 p.drouand@gmail.com
- Do not provide runvdr subpackage anymore; vdr builds for systems
  which support systemd
- Split languages files in a lang subpackage
- Do not copy INSTALL file in the documentation directory; vdr
  is not installed from sources
* Tue Apr 22 2014 seife+obs@b1-systems.com
- remove support for ancient distributions
- list of patches which fix stuff:
  vdr-1.7.21-pluginmissing.patch - don't die on missing plugin
  vdr-1.7.29-menuselection.patch
  vdr-1.7.36-wareagle.patch - wareagle icons
  vdr-2.0.6-wareagle-fix.patch
  vdr-2.0.3-dynamite.patch - allow the dynamite plugin
  vdr-2.0.4-MainMenuHooks-v1_0_1.patch
* Thu Apr 10 2014 seife+obs@b1-systems.com
- vdr.macros: remove vdr_old_plugin_* and vdr_install_plugin_*,
  all current users are converted now
* Sun Apr  6 2014 seife+obs@b1-systems.com
- fix broken record filenames in e.g. streamdev, bug in wareagle
  patch (vdr-2.0.6-wareagle-fix.patch)
* Wed Apr  2 2014 seife+obs@b1-systems.com
- small fix for classic runvdr init script
- recommend instead of suggest runvdr-extreme on >=12.1, vdr-runvdr
  on < 12.2
* Sun Mar 30 2014 seife+obs@b1-systems.com
- fix build on SLES11
- remove unused vdr_old_dvbapi.diff and Make.config
* Sun Mar 30 2014 seife+obs@b1-systems.com
- split off init script into vdr-runvdr package
  It is recommended to use runvdr-extreme-systemd instead
* Sun Mar 30 2014 seife+obs@b1-systems.com
- avoid putting build time into locale files, causing republishing
- install msgmerge wrapper to /usr/share/vdr to make it usable
  by plugins
* Sun Mar 30 2014 seife+obs@b1-systems.com
- update to vdr 2.0.6
  - see HISTORY file for changes
  - vdrapi version bumped to 2.0.6
* Sat Mar 29 2014 seife+obs@b1-systems.com
- vdr.macros: allow empty srcdir in vdr_old_plugin_make
* Sat Mar 29 2014 seife+obs@b1-systems.com
- vdr.macros: set vdr_includedir back to /usr/include/vdr
* Sat Mar 29 2014 seife+obs@b1-systems.com
- remove plugin build macros
* Sun Jan 12 2014 wagner-thomas@gmx.at
- Update to vdr 2.0.5
* Tue Nov 26 2013 hpj@urpla.net
- Update to vdr 2.0.4
* Tue Jun  4 2013 hpj@urpla.net
- Adjust vdr macros
* Tue Jun  4 2013 hpj@urpla.net
- Update to vdr 2.0.2
* Sun Dec 16 2012 seife+obs@b1-systems.com
- add vdr_install_plugin_new macro for newer plugins
* Mon Nov 19 2012 seife+obs@b1-systems.com
- add vdr-1.6.0-bnc786040-use-v4l2.patch (bnc#786040), based on
  http://sources.gentoo.org/cgi-bin/viewvc.cgi/gentoo-x86/
    media-video/vdr/files/vdr-1.6.0-use-v4l2.patch
- this obsoletes vdr-v4l-2.6.38.patch
* Sat Jun 16 2012 bwiedemann@suse.com
- Add vdr-FcFontSort-72c5ec3.diff to fix bug
  vdr: fcmatch.c:850: IA__FcFontSort: Assertion `result != ((void *)0)' failed.
* Sat Mar 17 2012 dimstar@opensuse.org
- Add vdr-gcc47.patch: Fix build with gcc 4.7.
* Thu Jul  7 2011 idonmez@novell.com
- Add vdr-v4l-2.6.38.patch: use the new v4l interface
* Wed May  4 2011 idoenmez@novell.com
- Add vdr-1.6.0-gcc46.patch: provide constructors for const-classes
* Tue Aug  3 2010 lnussel@suse.de
- update README from wiki
* Tue Oct 13 2009 lnussel@suse.de
- vdr has a new home now, change urls
* Tue Oct  6 2009 lnussel@suse.de
- don't restart vdr if exit was requested by init script (bnc#463453)
* Mon Jun  8 2009 lnussel@suse.de
- remove dvb from BuildRequires, not actually needed
- update const patch with hunk from upstream
* Wed Jun  3 2009 lnussel@suse.de
- fix build with gcc 4.4
- add vdr maintenance patches 1 and 2
- Provide 'vdr(abi)' instead of 'vdrapi' as Fedora does
* Mon Mar  9 2009 lnussel@suse.de
- fix build with kernel 2.6.29
* Fri Dec  5 2008 lnussel@suse.de
- split off devel package
- create rpm macros file to simplify plugin packages
* Tue Aug 19 2008 lnussel@suse.de
- set Required-Stop in init script
* Sun May  4 2008 lnussel@suse.de
- update channels.conf
* Fri Apr 11 2008 werner@suse.de
- Also check existence of ncurses libs not only headers
* Thu Apr 10 2008 werner@suse.de
- Enable the plugin skincurses to use several ncurses variations
* Mon Mar 31 2008 lnussel@suse.de
- major version update to 1.6.0:
  * DVB subtitle support
  * UTF-8 support
  * now uses freetype fonts for OSD
  * better CAM handling
- recommend instead of require dvb
* Tue Nov  6 2007 lnussel@suse.de
- add PreReq for fillup and insserv
* Wed Oct 31 2007 dmueller@suse.de
- provide vdr-devel (#291443)
* Thu Jun 21 2007 lnussel@suse.de
- require $remote_fs in init script (#285548)
* Mon Jun 11 2007 lnussel@suse.de
- install libsi header files, needed by epgsearch plugin
* Thu May 31 2007 lnussel@suse.de
- add rpmlint suppression for /usr/include/vdr
* Sun May 13 2007 lnussel@suse.de
- new version 1.4.7
  * Fixed a busy loop in fast forward if the next video data file is
    missing
  * Fixed handling frequencies in NitFilter::Process()
  * Fixed handling ChannelUp/Down keys if there is currently a
    replay running
  * Increased the maximum number of CA system ids to cope with the
    AlphaCrypt CAM's version 3.11 firmware.
* Mon Apr  2 2007 lnussel@suse.de
- add ncurses-devel to BuildRequires
* Mon Mar 26 2007 lnussel@suse.de
- add virtual provide 'vdrapi'
* Sun Mar  4 2007 lnussel@suse.de
- new version 1.4.6
  * Fixed i18n characters for the Hungarian texts.
  * Now using cPipe instead of popen() in cCommand::Execute() to
    avoid problems with open file handles when starting background
    commands.
  * Removed 'assert(0)' from cDvbSpuDecoder::setTime().
  * Fixed a possible crash when loading an invalid XPM file.
  * Updated satellite names in 'sources.conf'.
  * Fixed handling error status in cDvbTuner::GetFrontendStatus().
  * Updated the Finnish OSD texts.
* Tue Jan 23 2007 lnussel@suse.de
- fix compile warning of vdr-genindex.c
* Thu Jan 11 2007 lnussel@suse.de
- new version 1.4.5
  * Fixed a possible segfault in cSkins::Message()
  * Fixed a possible crash in remux.c on 64-bit machines
  * Now calling cPluginManager::Active() only if VDR is really
    trying to shut down, and waiting for 5 minutes before calling it
    again
  * Fixed a possible segfault if VDR gets terminated while a message is displayed
* Wed Nov 15 2006 lnussel@suse.de
- new version 1.4.4
  * epg and language code bug fixes
* Tue Sep 26 2006 lnussel@suse.de
- rename vdr13 package to vdr
* Mon Sep 25 2006 lnussel@suse.de
- new version 1.4.3
  * fix issues with expired VPS timers
* Mon Aug 28 2006 lnussel@suse.de
- new version 1.4.2
  countless bugfixes
* Sun Jun 11 2006 lnussel@suse.de
- new version 1.4.1
  - Changed the log messages when grabbing an image from 'isyslog()'
  to 'dsyslog()' so that they can be suppressed in normal operation
  mode to avoid clogging the log file in case this function is used
  frequently (suggested by Helmut Auer).
* Fri Jun  2 2006 lnussel@suse.de
- remove unused patches
* Tue May 30 2006 lnussel@suse.de
- add maintenance patches 1 and 2
* Tue May  2 2006 lnussel@suse.de
- new version 1.4.0
- fix runvdr script not working with plugins that have a dash in the
  name (#171518)
* Wed Apr 26 2006 lnussel@suse.de
- apply vdr-1.3.48-apiversion.diff and vdr-1.3.48-inteditzero.diff
* Tue Apr 25 2006 lnussel@suse.de
- new version 1.3.48 (RC for 1.4.0)
* Wed Mar 29 2006 lnussel@suse.de
- new version 1.3.45
* Sun Feb 19 2006 lnussel@suse.de
- GIGA moved to different transponder
* Sun Feb  5 2006 lnussel@suse.de
- update channel frequencies
- add console F-keys to remote.conf
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 ro@suse.de
- added (empty) rest of rc script header
* Sun Jan 15 2006 lnussel@suse.de
- new version 1.3.39
* Sun Jan  8 2006 lnussel@suse.de
- new version 1.3.38
* Tue Nov 29 2005 lnussel@suse.de
- new version 1.3.37
* Fri Nov 11 2005 lnussel@suse.de
- new version 1.3.36
* Thu Sep 29 2005 lnussel@suse.de
- new version 1.3.33
* Sun Sep 18 2005 kukuk@suse.de
- Add libcap-devel to nfb
* Tue Aug 23 2005 lnussel@suse.de
- new version 1.3.30
* Fri Jul 22 2005 lnussel@suse.de
- don't patch stuff in the rpm source dir
- use %%jobs
* Tue Jun 28 2005 lnussel@suse.de
- use getpw*_r functions in su patch to make it usable with thread
  poison patched vdrs (by Ville Skyttä)
* Sun Jun 26 2005 lnussel@suse.de
- new version 1.3.27
* Mon Jun 13 2005 lnussel@suse.de
- new version 1.3.26
* Wed Jun  8 2005 lnussel@suse.de
- new package
